@@ -7,6 +7,7 @@ from connect.eaas.core.validation.validators.base import (  # noqa
 )
 from connect.eaas.core.validation.validators.eventsapp import validate_eventsapp  # noqa
 from connect.eaas.core.validation.validators.webapp import validate_webapp  # noqa
+from connect.eaas.core.validation.validators.tfnapp import validate_tfnapp  # noqa
 
 
 def get_validators():
@@ -17,5 +18,6 @@ def get_validators():
         validate_eventsapp,
         validate_anvilapp,
         validate_webapp,
+        validate_tfnapp,
         validate_variables,
     ]
